# Hashpic

Hashpic creates an image from the MD5 hash of your input.

### Usage

```bash
> hashpic 'Hashpic rocks!'
```

This should create a file `output.png` in your current directory. 
The input `Hashpic rocks!` should create the following image:

![hashpic image](./rocks.png)